@@ -16,12 +16,18 @@ GetProducts<- function(){
   
   reader<- basicTextGatherer()
   header<- basicTextGatherer()
+  
   curlPerform(url = "http://daac.ornl.gov/cgi-bin/MODIS/GLBVIZ_1_Glb_subset/MODIS_webservice.pl",
               httpheader = header.fields,
               postfields = getproducts.xml,
               writefunction = reader$update,
               verbose=FALSE)
   
+  # Check the server is not down by insepcting the XML response for internal server error message.
+  if(grepl("Internal Server Error", reader$value())){
+    stop("Web service failure: the ORNL DAAC server seems to be down, please try again later. The online subsetting tool (http://daac.ornl.gov/cgi-bin/MODIS/GLBVIZ_1_Glb/modis_subset_order_global_col5.pl) will indicate when the server is up and running again.")
+  }
+  
   xmlres<- xmlRoot(xmlTreeParse(reader$value()))
   productsres<- xmlSApply( xmlres[[1]], 
                            function(x) xmlSApply(x,
